﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  CalcSettingsクラス
'
'  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
'
'  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
'  2016/02/04 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports Act.Dcws

''' <summary>
''' 距離計算サービスに使用する設定を指定します。
''' </summary>
Friend Class CalcSettings

    '==============================================================================================
    '  Public Constants
    '==============================================================================================
#Region "Public Constants"

    ''' <summary>
    ''' 管理サービスURLの既定値です。
    ''' </summary>
    Public Shared ReadOnly DefaultAdminUrl As String =
        "https://distcalc.act-inc.co.jp/dcadmin/admin.asmx"

    ''' <summary>
    ''' 使用する計算用道路データ（000で始まる）のNWIDの正規表現です。
    ''' </summary>
    ''' <remarks>"000"で始まるNWIDを表します。</remarks>
    Public Shared ReadOnly NWIDPattern As String = "^(000)"

    ''' <summary>
    ''' 経緯度の測地系を指定します。
    ''' </summary>
    ''' <remarks>Tokyo（日本測地系）</remarks>
    Public Shared ReadOnly Datum As Datum = Datum.Tokyo

    ''' <summary>
    ''' 経緯度の座標フォーマット識別子を指定します。
    ''' </summary>
    ''' <remarks>現在は常に0を指定します</remarks>
    Public Shared ReadOnly CoordinateFormat As Integer = 0

    ''' <summary>
    ''' 計算方法を指定します。
    ''' </summary>
    ''' <remarks>Time（時間最短）</remarks>
    Public Shared ReadOnly CalcKind As CalcKind = CalcKind.Time

    ''' <summary>
    ''' 使用交通機関を指定します。
    ''' 使用する交通機関が複数ある場合はその論理和を指定します。
    ''' </summary>
    Public Shared ReadOnly Transport As Transport = Transport.Highway

    ''' <summary>
    ''' ポリゴン種別を指定します。
    ''' </summary>
    ''' <remarks>SinglePolygon（単一ポリゴン）</remarks>
    Public Shared ReadOnly PolygonKind As PolygonKind = PolygonKind.SinglePolygon

    ''' <summary>
    ''' 到達ポリゴンのポリゴンレベルを指定します。
    ''' </summary>
    ''' <remarks>-1：凸型(簡易)ポリゴン
    ''' 0～20：凹凸型(通常)ポリゴン（大きいほど細かくなります）</remarks>
    Public Shared ReadOnly PolygonLevel As Integer = 10

    ''' <summary>
    ''' 到達ポリゴン内で到達できない範囲のポリゴンレベルを指定します。
    ''' </summary>
    ''' <remarks>-2：表示しない
    ''' -1：凸型(簡易)ポリゴン
    ''' 0～20：凹凸型(通常)ポリゴン（大きいほど細かくなります）</remarks>
    Public Shared ReadOnly DonutPolygonLevel As Integer = -2

    ''' <summary>
    ''' 計算時に使用する機能を指定します。
    ''' 複数の機能を指定する場合はその論理和を指定します。
    ''' </summary>
    ''' <remarks>ExpandMiddle（中間リンク補間）</remarks>
    Public Shared ReadOnly PolygonDetail As PolygonDetail = PolygonDetail.ExpandMiddle

#End Region

    '==============================================================================================
    '  Public Property
    '==============================================================================================
#Region "Public Property"

    ''' <summary>
    ''' 通信プロトコルにSSLを使用するかどうかを指定します。
    ''' </summary>
    ''' <remarks>true（SSLを使用する）、false（SSLを使用しない）</remarks>
    Public Shared Property UseSsl As Boolean = False

#End Region

End Class
