﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  CsvWriterクラス
'
'  Copyright (c) 2016, Advanced Core Technologies, Inc. All Rights Reserved.
'
'  2016/02/08 Rev.1.0.0.0 MOTO VB.NET版作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports System.IO

Namespace Act.VisualBasic.Utilities.CsvIO

    Public Class CsvWriter
        Implements IDisposable

        '==========================================================================================
        '  Constructors
        '==========================================================================================
#Region "Constructors"

        ''' <summary>
        ''' 指定したTextWriterを使用して初期化します。
        ''' </summary>
        ''' <param name="writer">書き込みを行うTextWriter</param>
        Public Sub New(ByVal writer As TextWriter)
            writer_ = writer
        End Sub

#End Region

        '==========================================================================================
        '  Private Fields
        '==========================================================================================
#Region "Private Fields"

        ''' <summary>
        ''' Dispose済みフラグです。
        ''' </summary>
        Private alreadyDisposed_ As Boolean

        ''' <summary>
        ''' Writerのバッキングフィールドです。
        ''' </summary>
        Private writer_ As TextWriter

#End Region

        '==========================================================================================
        '  Properties
        '==========================================================================================
#Region "Properties"

        ''' <summary>
        ''' 書き込みを行うTextWriterを取得します。
        ''' </summary>
        Public ReadOnly Property Writer As TextWriter
            Get
                Return writer_
            End Get
        End Property

#End Region

        '==========================================================================================
        '  Public Methods
        '==========================================================================================
#Region "Public Methods"

        ''' <summary>
        ''' 指定された値をストリームまたは文字列へ書き込みます。
        ''' </summary>
        ''' <param name="value">書き込む文字列</param>
        ''' <param name="appendNewLine">末尾に改行文字列を書き込む場合はtrue、既定値はfalseです。</param>
        Public Sub WriteField(ByVal value As String,
                              Optional ByVal appendNewLine As Boolean = False)
            If value Is Nothing Then
                Throw New ArgumentNullException("value")
            End If

            If appendNewLine Then
                value += Environment.NewLine
            End If
            Writer.Write(value)
        End Sub

        ''' <summary>
        ''' 指定されたレコードと末尾に改行コードをストリームまたは文字列へ書き込みます。
        ''' </summary>
        ''' <param name="record">書き込むCSVレコード</param>
        Public Sub WriteRecord(ByVal record As CsvRecord)
            If record Is Nothing Then
                Throw New ArgumentNullException("record")
            End If

            Writer.WriteLine(record)
        End Sub

        ''' <summary>
        ''' 指定された複数のレコードをストリームまたは文字列へ書き込みます。
        ''' </summary>
        ''' <param name="records">書き込むCSVレコードのコレクション</param>
        Public Sub WriteRecords(ByVal records As IEnumerable(Of CsvRecord))
            If records Is Nothing Then
                Throw New ArgumentNullException("records")
            End If

            For Each record In records
                WriteRecord(record)
            Next
        End Sub

#End Region

        '==========================================================================================
        '  IDisposable
        '==========================================================================================
#Region "IDisposable"

        Public Sub Dispose() Implements IDisposable.Dispose
            Dispose(True)
            GC.SuppressFinalize(Me)
        End Sub

        Protected Overridable Sub Dispose(ByVal disposing As Boolean)
            If alreadyDisposed_ Then
                Return
            End If

            If disposing Then
                ' マネージリソースの解放
                Writer.Dispose()
            End If
            ' アンマネージリソースの解放

            alreadyDisposed_ = True
        End Sub

        Protected Overrides Sub Finalize()
            Dispose(False)
        End Sub

#End Region

    End Class

End Namespace

