﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  Userクラス
'
'  Copyrights (c) 2016 Advanced Core Technologies, Inc. All rights reserved.
'
'  2016/02/03 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

''' <summary>
''' ユーザクラス
''' </summary>
Friend Class User

    '==============================================================================================
    '  Constructors
    '==============================================================================================
#Region "Constructors"

    ''' <summary>
    ''' 指定されたログイン情報とSSLモードを使用して初期化します。
    ''' </summary>
    ''' <param name="userID">距離計算サービスのユーザーID</param>
    ''' <param name="password">距離計算サービスのパスワード</param>
    ''' <param name="adminUrl">距離計算サービスの管理サーバーURL</param>
    ''' <param name="sslMode">SSLの使用フラグ</param>
    Public Sub New(ByVal userID As String, ByVal password As String, ByVal adminUrl As String,
                   ByVal sslMode As Boolean)
        userID_ = userID
        password_ = password
        adminUrl_ = adminUrl
        sslMode_ = sslMode
    End Sub

#End Region

    '==============================================================================================
    '  Private Fields
    '==============================================================================================
#Region "Private Fields"

    ''' <summary>
    ''' ユーザーIDのバッキングフィールドです。
    ''' </summary>
    Private userID_ As String

    ''' <summary>
    ''' パスワードのバッキングフィールドです。
    ''' </summary>
    Private password_ As String

    ''' <summary>
    ''' 管理サーバーURLのバッキングフィールドです。
    ''' </summary>
    Private adminUrl_ As String

    ''' <summary>
    ''' SSLモードのバッキングフィールドです。
    ''' </summary>
    Private sslMode_ As Boolean

    ''' <summary>
    ''' 最終距離計算日時のバッキングフィールドです。
    ''' </summary>
    Private lastDCTime_ As DateTime

    ''' <summary>
    ''' 最終住所検索日時のバッキングフィールドです。
    ''' </summary>
    ''' <remarks></remarks>
    Private lastGCTime_ As DateTime

#End Region

    '==============================================================================================
    '  Properties
    '==============================================================================================
#Region "Properties"

    ''' <summary>
    ''' ユーザIDを取得します。
    ''' </summary>
    Public ReadOnly Property UserID As String
        Get
            Return userID_
        End Get
    End Property

    ''' <summary>
    ''' パスワードを取得します。
    ''' </summary>
    Public ReadOnly Property Password As String
        Get
            Return password_
        End Get
    End Property

    ''' <summary>
    ''' 管理サーバーURLを取得します。
    ''' </summary>
    Public ReadOnly Property AdminUrl As String
        Get
            Return Utilities.ChangeProtocol(adminUrl_, SslMode)
        End Get
    End Property

    ''' <summary>
    ''' SSLモードを取得します。
    ''' </summary>
    Public ReadOnly Property SslMode As Boolean
        Get
            Return sslMode_
        End Get
    End Property

    ''' <summary>
    ''' 最終距離計算日時を取得します。
    ''' </summary>
    Public ReadOnly Property LastDCTime As DateTime
        Get
            Return lastDCTime_
        End Get
    End Property

    ''' <summary>
    ''' 最終住所検索日時を取得します。
    ''' </summary>
    Public ReadOnly Property LastGCTime As DateTime
        Get
            Return lastGCTime_
        End Get
    End Property

    ''' <summary>
    ''' 利用する計算用道路データ情報を取得または設定します。
    ''' </summary>
    Public Property NWInfo As DCAdmin.NWInfo

    ''' <summary>
    ''' 距離計算サービスのユーザー情報を取得または設定します。
    ''' </summary>
    Public Property UserInfo As DCAdmin.UserInformation2

#End Region

    '==============================================================================================
    '  Public Methods
    '==============================================================================================
#Region "Public Methods"

    ''' <summary>
    ''' 管理サービス用環境設定オブジェクトを取得します。
    ''' </summary>
    ''' <returns>管理サービス用環境設定オブジェクト</returns>
    Public Function GetAdminEnviron() As DCAdmin.Environ
        Return New DCAdmin.Environ With {.UserID = UserID,
                                         .UUID = Password}
    End Function

    ''' <summary>
    ''' 最終距離計算日時を更新します。
    ''' </summary>
    Public Sub UpdateLastDCTime()
        lastDCTime_ = DateTime.Now()
    End Sub

    ''' <summary>
    ''' 最終住所検索日時を更新します。
    ''' </summary>
    Public Sub UpdateLastGCTime()
        lastGCTime_ = DateTime.Now()
    End Sub

#End Region

End Class
