﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  UserSettingsクラス
'
'  Copyrights (c) 2016 Advanced Core Technologies, Inc. All rights reserved.
'
'  2016/02/04 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports System.IO
Imports System.Runtime.Serialization
Imports System.Text
Imports System.Xml
Imports ACT.Dcws

''' <summary>
''' ユーザーの設定を保存、復元します。
''' </summary>
<DataContract>
Friend Class UserSettings
    '==============================================================================================
    '  Constructors
    '==============================================================================================
#Region "Constructors"

    ''' <summary>
    ''' 静的コンストラクターです。
    ''' </summary>
    Shared Sub New()
        SettingFilePath = Path.Combine(AppPathDirectoryName, SettingFileName)
        UsersGuideFilePath = Path.Combine(AppPathDirectoryName, UsersGuideFileName)
    End Sub

#End Region

    '==============================================================================================
    '  Public Constants
    '==============================================================================================
#Region "Public Constants"

    ''' <summary>
    ''' 設定ファイルのパスです。
    ''' </summary>
    Public Shared ReadOnly SettingFilePath As String

    ''' <summary>
    ''' ユーザーズガイドのパスです。
    ''' </summary>
    Public Shared ReadOnly UsersGuideFilePath As String

#End Region

    '==============================================================================================
    '  Private Constants
    '==============================================================================================
#Region "Private Constants"

    ''' <summary>
    ''' 実行ファイルのフォルダ名です。
    ''' </summary>
    Private Shared ReadOnly AppPathDirectoryName As String =
        Path.GetDirectoryName(System.Windows.Forms.Application.ExecutablePath)

    ''' <summary>
    ''' 設定ファイルのファイル名です。
    ''' </summary>
    Private Shared ReadOnly SettingFileName As String = "CalcArea.config"

    ''' <summary>
    ''' ユーザーズガイドのファイル名です。
    ''' </summary>
    Private Shared ReadOnly UsersGuideFileName As String = "サンプルツール・ユーザーズガイド.pdf"

#End Region

    '==============================================================================================
    '  Properties
    '==============================================================================================
#Region "Properties"

    ''' <summary>
    ''' 距離計算サービスに接続するユーザーIDを取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property UserID As String

    ''' <summary>
    ''' 距離計算サービスに接続するパスワードを取得または設定します。
    ''' </summary>
    Public Property Password As String

    ''' <summary>
    ''' 距離計算サービスの管理サービスURLを取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property AdminUrl As String

    ''' <summary>
    ''' 入力ファイルのパスを取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property InputFilePath As String

    ''' <summary>
    ''' 出力ファイルのパスを取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property OutputFilePath As String

    ''' <summary>
    ''' 計算範囲の種別を取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property AreaKind As AreaKind

    ''' <summary>
    ''' 計算範囲を取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property AreaRange As Integer

    ''' <summary>
    ''' 範囲方向を取得または設定します。
    ''' </summary>
    <DataMember>
    Public Property AreaDirection As AreaDirection

#End Region

    '==============================================================================================
    '  Public Methods
    '==============================================================================================
#Region "Public Methods"

    ''' <summary>
    ''' このインスタンスをXMLシリアライズして、指定されたファイルに書き込みます。
    ''' </summary>
    ''' <param name="filePath">保存先のパス文字列</param>
    ''' <returns>書き込みに成功した場合はtrue、それ以外の場合はfalse。</returns>
    Public Function Save(ByVal filePath As String) As Boolean
        If String.IsNullOrWhiteSpace(filePath) Then
            Throw New ArgumentNullException("filePath")
        End If

        Dim directoryName As String = Path.GetDirectoryName(filePath)
        If Not Directory.Exists(directoryName) Then
            Throw New DirectoryNotFoundException(filePath + "は存在しません")
        End If

        Try
            Using strmWriter As New StreamWriter(filePath, False, New UTF8Encoding(False))
                Using writer As XmlWriter = XmlWriter.Create(strmWriter)
                    Dim serializer As New DataContractSerializer(GetType(UserSettings))
                    serializer.WriteObject(writer, Me)
                End Using
            End Using
        Catch
            Return False
        End Try

        Return True
    End Function

    ''' <summary>
    ''' 指定されたパスからUserSettingsオブジェクトをデシリアライズして返します。
    ''' </summary>
    ''' <param name="filePath">復元のパス文字列</param>
    ''' <returns>デシリアライズしたUserSettingsオブジェクト、失敗した場合はnull。</returns>
    Public Shared Function Load(ByVal filePath As String) As UserSettings
        If String.IsNullOrWhiteSpace(filePath) Then
            Throw New ArgumentNullException("filePath")
        End If

        Dim settings As UserSettings = Nothing
        Try
            Using strmReader As New StreamReader(filePath, New UTF8Encoding(False))
                Using reader As XmlReader = XmlReader.Create(strmReader)
                    Dim serializer As New DataContractSerializer(GetType(UserSettings))
                    settings = CType(serializer.ReadObject(reader), UserSettings)
                End Using
            End Using
        Catch
            '
        End Try

        Return settings
    End Function

#End Region

End Class
