﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  Utilitiesクラス
'
'  Copyrights (c) 2016 Advanced Core Technologies, Inc. All rights reserved.
'
'  2016/02/03 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Friend Class Utilities

    '==============================================================================================
    '  Constructors
    '==============================================================================================
#Region "Constructors"

    ''' <summary>
    ''' インスタンス作成防止用コンストラクターです。
    ''' </summary>
    Private Sub New()
        '
    End Sub

#End Region

    '==============================================================================================
    '  Public Methods
    '==============================================================================================
#Region "Public Methods"

    ''' <summary>
    ''' 指定されたURLとSSLモードを使用して、指定されたプロトコルに変更したURLを返します。
    ''' </summary>
    ''' <param name="url">変更するURL</param>
    ''' <param name="sslMode">SSLモード</param>
    ''' <returns>変更後のURL。</returns>
    Public Shared Function ChangeProtocol(ByVal url As String, ByVal sslMode As Boolean) As String
        Dim newUri As New UriBuilder(url) With {.Scheme = If(sslMode, "https", "http"),
                                                .Port = -1}

        Return newUri.Uri.ToString()
    End Function

    ''' <summary>
    ''' 管理サービス用環境設定オブジェクトから距離計算サービス環境設定オブジェクトを取得します
    ''' </summary>
    ''' <param name="adminEnviron">管理サービス用環境設定オブジェクト</param>
    ''' <returns>距離計算サービス環境設定オブジェクト</returns>
    Public Shared Function GetDCServiceEnviron(ByVal adminEnviron _
                                               As DCAdmin.Environ) As DCService.Environ
        Return New DCService.Environ With {.UserID = adminEnviron.UserID,
                                           .UUID = adminEnviron.UUID,
                                           .Host = adminEnviron.Host,
                                           .Port = adminEnviron.Port}
    End Function

    ''' <summary>
    ''' 管理サービス用環境設定オブジェクトから住所検索サービス環境設定オブジェクトを取得します
    ''' </summary>
    ''' <param name="adminEnviron">管理サービス用環境設定オブジェクト</param>
    ''' <returns>住所検索サービス環境設定オブジェクト</returns>
    Public Shared Function GetGCServiceEnviron(ByVal adminEnviron _
                                               As DCAdmin.Environ) As GCService.Environ
        Return New GCService.Environ With {.UserID = adminEnviron.UserID,
                                           .UUID = adminEnviron.UUID,
                                           .Host = adminEnviron.Host,
                                           .Port = adminEnviron.Port}
    End Function

#End Region

End Class
